==> libsfml_1.2.orig.tar.gz: libsfml-1.2.orig/include/SFML/Window/WindowStyle.hpp <==
////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007 Laurent Gomila (laurent.gom@gmail.com)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

#ifndef SFML_WINDOWSTYLE_HPP
#define SFML_WINDOWSTYLE_HPP


namespace sf
{

////////////////////////////////////////////////////////////
/// Enumeration of window creation styles
////////////////////////////////////////////////////////////
namespace Style
{
    enum
    {
        NoStyle    = 0,      ///< No style (this flag and all others are mutually exclusive)
        Resize     = 1 << 0, ///< Window can be resized
        Close      = 1 << 1, ///< Window can be closed
        Fullscreen = 1 << 2  ///< Fullscreen mode (this flag and all others are mutually exclusive)
    };
}


} // namespace sf


#endif // SFML_WINDOWSTYLE_HPP

==> libsfml_1.3.orig.tar.gz: libsfml-1.3.orig/include/SFML/Window/WindowStyle.hpp <==
////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007-2008 Laurent Gomila (laurent.gom@gmail.com)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

#ifndef SFML_WINDOWSTYLE_HPP
#define SFML_WINDOWSTYLE_HPP


namespace sf
{

////////////////////////////////////////////////////////////
/// Enumeration of window creation styles
////////////////////////////////////////////////////////////
namespace Style
{
    enum
    {
        None       = 0,      ///< No border / title bar (this flag and all others are mutually exclusive)
        Titlebar   = 1 << 0, ///< Title bar + fixed border
        Resize     = 1 << 1, ///< Titlebar + resizable border + maximize button
        Close      = 1 << 2, ///< Titlebar + close button
        Fullscreen = 1 << 3  ///< Fullscreen mode (this flag and all others are mutually exclusive)
    };
}


} // namespace sf


#endif // SFML_WINDOWSTYLE_HPP
